
<img src="docs/source/_static/openbte_logo.png" width="300">

[![license](https://img.shields.io/github/license/romanodev/openbte?style=plastic)](https://github.com/romanodev/OpenBTE/blob/master/LICENSE)
[![documentation](https://readthedocs.org/projects/pip/badge/?version=latest&style=plastic)](https://openbte.readthedocs.io/en/latest/)
[![downloads](https://img.shields.io/pypi/dm/openbte?style=plastic)](https://pypi.org/project/openbte/)
[![docker](https://img.shields.io/docker/pulls/romanodev/openbte?style=plastic)](https://hub.docker.com/r/romanodev/openbte)

OpenBTE solves the Linearized Boltzmann Transport equation, with current focus on steady-state phonon transport.












